//
//  XYChannel.h
//  XYChannel
//
//  Created by imac on 2020/1/2.
//  Copyright © 2020 imac. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "XYChannelProtocol.h"

typedef void(^CompletionBlock)(NSDictionary *resultDic);

//MARK: - 回调
//MARK: - init callback
@protocol ChannelInitDelegate <NSObject>
/*
 初始化成功回调
 */
- (void)channelDidInitSuccess;


/*
 初始化失败回调
 */
- (void)channelDidInitFail;

@end

//MARK: - 用户登录，注销，切换账号，实名认证
@protocol ChannelLoginDelegate <NSObject>
/*
 登录成功回调
 uid 登录账号唯一标识，NSString
 account 登录账号，NSString
 token token信息，NSString
 */
- (void)channelDidLoginSuccess:(NSDictionary *)result;

/// 登录失败回调
/// @param result 返回数据
- (void)channelDidLoginFailure:(NSDictionary *)result;

//切换了账号
- (void)channelDidexchangeAccount:(NSDictionary *)lastAccount toAccount:(NSDictionary *)account;

/*
 实名认证成功回调
 */
- (void)getfcmSuccess:(NSDictionary *)result;

/*
 注销回调
 */
- (void)channelDidLogoutSuccess;

/// 登录框关闭回调
- (void)chanelDidLoginClose;

//–––––––– add by 2022.11.23
-(void)channelDidUploadRoleSuccess;
//––––––––
@end

//MARK: - 支付回调
@protocol ChannelPayDelegate <NSObject>
/*
 支付成功回调
 */
- (void)channelDidPaySuccess;
- (void)channelDidPaySuccess:(NSDictionary *)dic;
/*
 支付失败回调
 */
- (void)channelDidPayFailed;
- (void)channelDidPayFailed:(NSDictionary *)dic;

@end

@interface XYChannel :NSObject
+ (instancetype)sharedInstance;
//获取下游编号
- (NSString *)channelID;
//下游版本号
- (NSString *)channelVersion;
@property (nonatomic,strong) NSString *appId;
@property (nonatomic,strong) NSDictionary *sdkInitParam;
//回调对象
@property (nonatomic,weak) id<ChannelInitDelegate> initDelegate;
@property (nonatomic,weak) id<ChannelLoginDelegate> loginDelegate;
@property (nonatomic,weak) id<ChannelPayDelegate> payDelegate;
//初始化
//- (BOOL)initChannelWithParam:(NSDictionary *)param Application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;
- (void)initChannelWithParam:(NSDictionary *)param;

//登录
- (void)login;
//注销
- (void)loginOut;
//切换账号，注销并弹出登录
- (void)exchangeAccount;
//禁止注册
//- (void)forbidReg:(BOOL)isReg;
//上传角色
-(void)updaterole:(NSDictionary *)roledic ;
//支付
- (void)payWithOrderInfo:(NSDictionary *)orderdic;
//MARK: - 悬浮球
//显示悬浮球
- (void)showFloatMenu;
//隐藏悬浮球
- (void)hideFloatMenu;

//MARK: - 实名认证相关
/// 获取实名认证状态
/// @param uid 用户id
/// @param block 状态回调 NO:未认证 YES:已认证
- (void)getRealNameStatusWithUid:(NSString *)uid Block:(void (^)(BOOL status))block;

/// 显示实名认证窗口
/// @param typeBlock 回调
- (void)showRealNameAuthenticationView:(CompletionBlock)typeBlock;

- (void)getAgeWithUid:(NSString *)uid Block:(void (^)(NSString *age))block;
//MARK: - 其他
//设置日志等级 YES 开启; NO 关闭. 默认关闭
- (void)setLogLevel:(BOOL)level;
- (NSString *)userID;

/// 显示隐私协议弹窗
- (void)showProtocolView;

//MARK:- lifecycle
//必需实现
- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url options:(NSDictionary <NSString *, id>*)options;
- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(NSString *)sourceApp annotation:(id)annotation;
- (void)applicationWillEnterForeground:(UIApplication *)application;
- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url;

- (BOOL)application:(UIApplication *)application continueUserActivity:(NSUserActivity *)userActivity restorationHandler:(void(^)(NSArray<id<UIUserActivityRestoring>> * __nullable restorableObjects))restorationHandler;
- (void)application:(UIApplication*)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData*)deviceToken;
- (void)application:(UIApplication*)application didFailToRegisterForRemoteNotificationsWithError:(NSError*)error;
- (void)application:(UIApplication *)application didReceiveRemoteNotification:(NSDictionary *)userInfo;
@end




